@@ -3,8 +3,8 @@
 /*
     This file is part of Magnum.
 
-    Copyright © 2010, 2011, 2012, 2013, 2014, 2015, 2016, 2017, 2018, 2019
-              Vladimír Vondruš <mosra@centrum.cz>
+    Copyright © 2010, 2011, 2012, 2013, 2014, 2015, 2016, 2017, 2018, 2019,
+                2020 Vladimír Vondruš <mosra@centrum.cz>
 
     Permission is hereby granted, free of charge, to any person obtaining a
     copy of this software and associated documentation files (the "Software"),
@@ -31,6 +31,7 @@
 
 #include "Player.h"
 
+#include <Corrade/Containers/GrowableArray.h>
 #include <Corrade/Containers/Optional.h>
 #include <Corrade/Containers/Reference.h>
 
@@ -60,10 +61,10 @@ namespace Implementation {
 template<class T, class K> struct Player<T, K>::Track  {
     /* Not sure why is this still needed for emplace_back(). It's 2018,
        COME ON  ¯\_(ツ)_/¯ */
-    /*implicit*/ Track(const TrackViewStorage<K>& track, void (*advancer)(const TrackViewStorage<K>&, K, std::size_t&, void*, void(*)(), void*), void* destination, void(*userCallback)(), void* userCallbackData, std::size_t hint) noexcept: track{track}, advancer{advancer}, destination{destination}, userCallback{userCallback}, userCallbackData{userCallbackData}, hint{hint} {}
+    /*implicit*/ Track(const TrackViewStorage<const K>& track, void (*advancer)(const TrackViewStorage<const K>&, K, std::size_t&, void*, void(*)(), void*), void* destination, void(*userCallback)(), void* userCallbackData, std::size_t hint) noexcept: track{track}, advancer{advancer}, destination{destination}, userCallback{userCallback}, userCallbackData{userCallbackData}, hint{hint} {}
 
-    TrackViewStorage<K> track;
-    void (*advancer)(const TrackViewStorage<K>&, K, std::size_t&, void*, void(*)(), void*);
+    TrackViewStorage<const K> track;
+    void (*advancer)(const TrackViewStorage<const K>&, K, std::size_t&, void*, void(*)(), void*);
     void* destination;
     void(*userCallback)();
     void* userCallbackData;
@@ -75,9 +76,9 @@ template<class T, class K> void Player<T, K>::advance(const T time, const std::i
     for(Player<T, K>& p: players) p.advance(time);
 }
 
-template<class T, class K> Player<T, K>::Player(Player<T, K>&&) = default;
+template<class T, class K> Player<T, K>::Player(Player<T, K>&&) noexcept = default;
 
-template<class T, class K> Player<T, K>& Player<T, K>::operator=(Player<T, K>&&) = default;
+template<class T, class K> Player<T, K>& Player<T, K>::operator=(Player<T, K>&&) noexcept = default;
 
 template<class T, class K> Player<T, K>::Player(): Player<T, K>{Implementation::DefaultScaler<T, K>::scale} {}
 
@@ -93,19 +94,19 @@ template<class T, class K> std::size_t Player<T, K>::size() const {
     return _tracks.size();
 }
 
-template<class T, class K> const TrackViewStorage<K>& Player<T, K>::track(std::size_t i) const {
+template<class T, class K> const TrackViewStorage<const K>& Player<T, K>::track(std::size_t i) const {
     CORRADE_ASSERT(i < _tracks.size(),
         /* Returning track 0 so we can test this w/ MSVC debug iterators */
         "Animation::Player::track(): index out of range", _tracks[0].track);
     return _tracks[i].track;
 }
 
-template<class T, class K> Player<T, K>& Player<T, K>::addInternal(const TrackViewStorage<K>& track, void(*const advancer)(const TrackViewStorage<K>&, K, std::size_t&, void*, void(*)(), void*), void* const destination, void(*const userCallback)(), void* const userCallbackData) {
+template<class T, class K> Player<T, K>& Player<T, K>::addInternal(const TrackViewStorage<const K>& track, void(*const advancer)(const TrackViewStorage<const K>&, K, std::size_t&, void*, void(*)(), void*), void* const destination, void(*const userCallback)(), void* const userCallbackData) {
     if(_tracks.empty() && _duration == Math::Range1D<K>{})
         _duration = track.duration();
     else
         _duration = Math::join(track.duration(), _duration);
-    _tracks.emplace_back(track, advancer, destination, userCallback, userCallbackData, 0);
+    arrayAppend(_tracks, Containers::InPlaceInit, track, advancer, destination, userCallback, userCallbackData, 0u);
     return *this;
 }
 
@@ -190,7 +191,7 @@ template<class T, class K> Player<T, K>& Player<T, K>::setState(State state, T t
         case State::Stopped: return stop();
     }
 
-    CORRADE_ASSERT_UNREACHABLE(); /* LCOV_EXCL_LINE */
+    CORRADE_INTERNAL_ASSERT_UNREACHABLE(); /* LCOV_EXCL_LINE */
 }
 
 namespace Implementation {
