@@ -3,8 +3,8 @@
 /*
     This file is part of Magnum.
 
-    Copyright © 2010, 2011, 2012, 2013, 2014, 2015, 2016, 2017, 2018, 2019
-              Vladimír Vondruš <mosra@centrum.cz>
+    Copyright © 2010, 2011, 2012, 2013, 2014, 2015, 2016, 2017, 2018, 2019,
+                2020 Vladimír Vondruš <mosra@centrum.cz>
 
     Permission is hereby granted, free of charge, to any person obtaining a
     copy of this software and associated documentation files (the "Software"),
@@ -80,7 +80,7 @@ possible to achieve the same with a @ref MultisampleTexture2D, support for it
 is rather sparse on OpenGL ES and completely nonexistent on WebGL or
 macOS / iOS.
 
-@section GL-Framebuffer-usage-multiple-output Multiple fragment shader outputs
+@section GL-Framebuffer-usage-multiple-outputs Multiple fragment shader outputs
 
 In a deferred rendering setup for example, a shader usually has more than one
 output. That's finally where non-zero @ref ColorAttachment and @ref mapForDraw()
